@@ -7,12 +7,20 @@ RDF Triple: subject, predicate, and object.
 import warnings
 from typing import TYPE_CHECKING
 
+try:
+    import rdflib  # pylint: disable=unused-import
+except ImportError as exc:
+    raise ImportError(
+        "rdflib is not installed.\nInstall it with:\n\n    pip install rdflib"
+    ) from exc
+
 from rdflib import BNode, Graph
 from rdflib import Literal as rdflibLiteral
 from rdflib import URIRef
 from rdflib.util import guess_format
 
 from tripper import Literal
+from tripper.utils import UnusedArgumentWarning
 
 if TYPE_CHECKING:  # pragma: no cover
     from collections.abc import Sequence
@@ -42,12 +50,11 @@ class RdflibStrategy:
     """Triplestore strategy for rdflib.
 
     Arguments:
-        base_iri: If given, initialise the triplestore from this storage.
-            When `close()` is called, the storage will be overwritten
-            with the current content of the triplestore.
+        base_iri: Unused by this backend.
         database: Unused - rdflib does not support multiple databases.
-        triplestore_url: Alternative URL to the underlying ontology if
-            `base_iri` is not resolvable.  Defaults to `base_iri`.
+        triplestore_url: If given, initialise the triplestore from this
+            storage.  When `close()` is called, the storage will be
+            overwritten with the current content of the triplestore.
         format: Format of storage specified with `base_iri`.
     """
 
@@ -58,10 +65,13 @@ class RdflibStrategy:
         triplestore_url: "Optional[str]" = None,
         format: "Optional[str]" = None,  # pylint: disable=redefined-builtin
     ) -> None:
-        # pylint: disable=unused-argument
+        if base_iri:
+            warnings.warn("base_iri", UnusedArgumentWarning, stacklevel=2)
+        if database:
+            warnings.warn("database", UnusedArgumentWarning, stacklevel=2)
+
         self.graph = Graph()
-        self.base_iri = base_iri
-        self.triplestore_url = triplestore_url if triplestore_url else base_iri
+        self.triplestore_url = triplestore_url
         if self.triplestore_url is not None:
             if format is None:
                 format = guess_format(self.triplestore_url)
